# -*- coding: utf-8 -*-
"""
.. invisible:
     _   _ _____ _     _____ _____
    | | | |  ___| |   |  ___/  ___|
    | | | | |__ | |   | |__ \ `--.
    | | | |  __|| |   |  __| `--. \
    \ \_/ / |___| |___| |___/\__/ /
     \___/\____/\_____|____/\____/

Created on Nov 5, 2013

███████████████████████████████████████████████████████████████████████████████

Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.

███████████████████████████████████████████████████████████████████████████████
"""


class MappedObjectsRegistry(type):
    """
    General purpose mapping between names and real classes.
    Derive your registry class from this base and the attribute defined by
    "mapping" will point to the dictionary between strings and classes, which
    metaclass is your registry class.
    """
    mapping = "You must define \"mapping\" static attribute in your metaclass"
    base = object

    def __init__(cls, name, bases, clsdict):
        yours = set(cls.mro())
        mine = set(cls.base.mro())
        left = yours - mine
        mapping = getattr(type(cls), cls.mapping, {})
        if len(left) > 1 and "MAPPING" in clsdict:
            mapping[clsdict["MAPPING"]] = cls
        setattr(type(cls), cls.mapping, mapping)
        super(MappedObjectsRegistry, cls).__init__(name, bases, clsdict)
